hub

package
v0.2.3 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 14, 2026 License: MIT Imports: 11 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Hub

type Hub struct {
	// contains filtered or unexported fields
}

Hub discovers running logpond instances and serves a single MCP endpoint that fans out queries to all live instances.

func New

func New(port int) *Hub

New creates a hub that will serve on the given port.

func (*Hub) Run

func (h *Hub) Run(ctx context.Context) error

Run starts the hub MCP server and blocks until ctx is cancelled.

Jump to